# Open pplx

I'm not gonna say what pplx stands for but you probably have a good idea :)

Super simple terminal application to ask questions and get answers. Powered by
local models + web search.

## Installation and Useage

Prerequisites: Install llama3 via ollama: https://ollama.com/library/llama3


Installation: `pip install opplx`

Useage: `opplx who fought in ufc 300`

Example Output:

```
Based on the search results provided, the main fights scheduled for UFC 300 are:

* Alex Pereira defending his light heavyweight title against former champion Jamahal Hill in the main event.

* The strawweight title fight between Zhang Weili and Yan Xiaonan as the co-main event.

* The "BMF" title bout between Justin Gaethje and Max Holloway as the featured contest.

* The middleweight bout between Bo Nickal and Cody Brundage opening the main card.

* The highly anticipated lightweight clash between former champion Charles Oliveira and Arman Tsarukyan as the lead-in bout.

* Additionally, the UFC president Dana White has confirmed that veteran lightweight Jim Miller will be fighting on the UFC 300 card.
```